@@ -1,15 +1,21 @@
-#! /bin/sh
+#!/bin/sh
 
 #BEGIN DEPEND------------------------------------------------------------------
-INPUT_MODULES='src/lib/perl5/COD/CIF/Data/CODNumbers.pm'
+INPUT_MODULE=src/lib/perl5/COD/CIF/Data/CODNumbers.pm
 #END DEPEND--------------------------------------------------------------------
 
-perl <<'END_SCRIPT'
+IMPORT_MODULE=$(\
+    echo ${INPUT_MODULE} | \
+    perl -pe "s|^src/lib/perl5/||; s/[.]pm$//; s|/|::|g;" \
+)
+
+perl -M"${IMPORT_MODULE}" \
+<<'END_SCRIPT'
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2021-07-30 19:52:52 +0300 (Fri, 30 Jul 2021) $ 
-#$Revision: 8840 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.7.0/tests/shtests/have_equiv_bibliographies_008.sh $
+#$Date: 2024-05-26 16:42:43 +0300 (Sun, 26 May 2024) $ 
+#$Revision: 10064 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.11.0/tests/shtests/have_equiv_bibliographies_008.sh $
 #------------------------------------------------------------------------------
 #*
 #* Unit test for the COD::CIF::Data::CODNumbers::have_equiv_bibliographies
@@ -21,7 +27,7 @@ perl <<'END_SCRIPT'
 use strict;
 use warnings;
 
-use COD::CIF::Data::CODNumbers;
+# use COD::CIF::Data::CODNumbers;
 
 my $entry_1 = {
     'bibliography' => {
